==> aws-cdk-lib-2.0.0-rc.14-sources.jar: software/amazon/awscdk/services/appconfig/CfnDeploymentProps.java <==
package software.amazon.awscdk.services.appconfig;

/**
 * Properties for defining a `AWS::AppConfig::Deployment`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T10:23:58.406Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_appconfig.CfnDeploymentProps")
@software.amazon.jsii.Jsii.Proxy(CfnDeploymentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDeploymentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::AppConfig::Deployment.ApplicationId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getApplicationId();

    /**
     * `AWS::AppConfig::Deployment.ConfigurationProfileId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationProfileId();

    /**
     * `AWS::AppConfig::Deployment.ConfigurationVersion`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationVersion();

    /**
     * `AWS::AppConfig::Deployment.DeploymentStrategyId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDeploymentStrategyId();

    /**
     * `AWS::AppConfig::Deployment.EnvironmentId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEnvironmentId();

    /**
     * `AWS::AppConfig::Deployment.Description`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * `AWS::AppConfig::Deployment.Tags`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDeploymentProps> {
        private java.lang.String applicationId;
        private java.lang.String configurationProfileId;
        private java.lang.String configurationVersion;
        private java.lang.String deploymentStrategyId;
        private java.lang.String environmentId;
        private java.lang.String description;
        private java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags;

        /**
         * Sets the value of {@link CfnDeploymentProps#getApplicationId}
         * @param applicationId `AWS::AppConfig::Deployment.ApplicationId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applicationId(java.lang.String applicationId) {
            this.applicationId = applicationId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getConfigurationProfileId}
         * @param configurationProfileId `AWS::AppConfig::Deployment.ConfigurationProfileId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationProfileId(java.lang.String configurationProfileId) {
            this.configurationProfileId = configurationProfileId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getConfigurationVersion}
         * @param configurationVersion `AWS::AppConfig::Deployment.ConfigurationVersion`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationVersion(java.lang.String configurationVersion) {
            this.configurationVersion = configurationVersion;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getDeploymentStrategyId}
         * @param deploymentStrategyId `AWS::AppConfig::Deployment.DeploymentStrategyId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentStrategyId(java.lang.String deploymentStrategyId) {
            this.deploymentStrategyId = deploymentStrategyId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getEnvironmentId}
         * @param environmentId `AWS::AppConfig::Deployment.EnvironmentId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environmentId(java.lang.String environmentId) {
            this.environmentId = environmentId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getDescription}
         * @param description `AWS::AppConfig::Deployment.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getTags}
         * @param tags `AWS::AppConfig::Deployment.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDeploymentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDeploymentProps build() {
            return new Jsii$Proxy(applicationId, configurationProfileId, configurationVersion, deploymentStrategyId, environmentId, description, tags);
        }
    }

    /**
     * An implementation for {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDeploymentProps {
        private final java.lang.String applicationId;
        private final java.lang.String configurationProfileId;
        private final java.lang.String configurationVersion;
        private final java.lang.String deploymentStrategyId;
        private final java.lang.String environmentId;
        private final java.lang.String description;
        private final java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applicationId = software.amazon.jsii.Kernel.get(this, "applicationId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configurationProfileId = software.amazon.jsii.Kernel.get(this, "configurationProfileId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configurationVersion = software.amazon.jsii.Kernel.get(this, "configurationVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.deploymentStrategyId = software.amazon.jsii.Kernel.get(this, "deploymentStrategyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.environmentId = software.amazon.jsii.Kernel.get(this, "environmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.lang.String applicationId, final java.lang.String configurationProfileId, final java.lang.String configurationVersion, final java.lang.String deploymentStrategyId, final java.lang.String environmentId, final java.lang.String description, final java.util.List<? extends software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applicationId = java.util.Objects.requireNonNull(applicationId, "applicationId is required");
            this.configurationProfileId = java.util.Objects.requireNonNull(configurationProfileId, "configurationProfileId is required");
            this.configurationVersion = java.util.Objects.requireNonNull(configurationVersion, "configurationVersion is required");
            this.deploymentStrategyId = java.util.Objects.requireNonNull(deploymentStrategyId, "deploymentStrategyId is required");
            this.environmentId = java.util.Objects.requireNonNull(environmentId, "environmentId is required");
            this.description = description;
            this.tags = (java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty>)tags;
        }

        @Override
        public final java.lang.String getApplicationId() {
            return this.applicationId;
        }

        @Override
        public final java.lang.String getConfigurationProfileId() {
            return this.configurationProfileId;
        }

        @Override
        public final java.lang.String getConfigurationVersion() {
            return this.configurationVersion;
        }

        @Override
        public final java.lang.String getDeploymentStrategyId() {
            return this.deploymentStrategyId;
        }

        @Override
        public final java.lang.String getEnvironmentId() {
            return this.environmentId;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("applicationId", om.valueToTree(this.getApplicationId()));
            data.set("configurationProfileId", om.valueToTree(this.getConfigurationProfileId()));
            data.set("configurationVersion", om.valueToTree(this.getConfigurationVersion()));
            data.set("deploymentStrategyId", om.valueToTree(this.getDeploymentStrategyId()));
            data.set("environmentId", om.valueToTree(this.getEnvironmentId()));
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_appconfig.CfnDeploymentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDeploymentProps.Jsii$Proxy that = (CfnDeploymentProps.Jsii$Proxy) o;

            if (!applicationId.equals(that.applicationId)) return false;
            if (!configurationProfileId.equals(that.configurationProfileId)) return false;
            if (!configurationVersion.equals(that.configurationVersion)) return false;
            if (!deploymentStrategyId.equals(that.deploymentStrategyId)) return false;
            if (!environmentId.equals(that.environmentId)) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.applicationId.hashCode();
            result = 31 * result + (this.configurationProfileId.hashCode());
            result = 31 * result + (this.configurationVersion.hashCode());
            result = 31 * result + (this.deploymentStrategyId.hashCode());
            result = 31 * result + (this.environmentId.hashCode());
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/appconfig/CfnDeploymentProps.java <==
package software.amazon.awscdk.services.appconfig;

/**
 * Properties for defining a `CfnDeployment`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.appconfig.*;
 * CfnDeploymentProps cfnDeploymentProps = CfnDeploymentProps.builder()
 *         .applicationId("applicationId")
 *         .configurationProfileId("configurationProfileId")
 *         .configurationVersion("configurationVersion")
 *         .deploymentStrategyId("deploymentStrategyId")
 *         .environmentId("environmentId")
 *         // the properties below are optional
 *         .description("description")
 *         .tags(List.of(TagsProperty.builder()
 *                 .key("key")
 *                 .value("value")
 *                 .build()))
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:07.253Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_appconfig.CfnDeploymentProps")
@software.amazon.jsii.Jsii.Proxy(CfnDeploymentProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnDeploymentProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The application ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getApplicationId();

    /**
     * The configuration profile ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationProfileId();

    /**
     * The configuration version to deploy.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getConfigurationVersion();

    /**
     * The deployment strategy ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDeploymentStrategyId();

    /**
     * The environment ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getEnvironmentId();

    /**
     * A description of the deployment.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * Metadata to assign to the deployment.
     * <p>
     * Tags help organize and categorize your AWS AppConfig resources. Each tag consists of a key and an optional value, both of which you define.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> getTags() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnDeploymentProps> {
        java.lang.String applicationId;
        java.lang.String configurationProfileId;
        java.lang.String configurationVersion;
        java.lang.String deploymentStrategyId;
        java.lang.String environmentId;
        java.lang.String description;
        java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags;

        /**
         * Sets the value of {@link CfnDeploymentProps#getApplicationId}
         * @param applicationId The application ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder applicationId(java.lang.String applicationId) {
            this.applicationId = applicationId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getConfigurationProfileId}
         * @param configurationProfileId The configuration profile ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationProfileId(java.lang.String configurationProfileId) {
            this.configurationProfileId = configurationProfileId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getConfigurationVersion}
         * @param configurationVersion The configuration version to deploy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder configurationVersion(java.lang.String configurationVersion) {
            this.configurationVersion = configurationVersion;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getDeploymentStrategyId}
         * @param deploymentStrategyId The deployment strategy ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder deploymentStrategyId(java.lang.String deploymentStrategyId) {
            this.deploymentStrategyId = deploymentStrategyId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getEnvironmentId}
         * @param environmentId The environment ID. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder environmentId(java.lang.String environmentId) {
            this.environmentId = environmentId;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getDescription}
         * @param description A description of the deployment.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link CfnDeploymentProps#getTags}
         * @param tags Metadata to assign to the deployment.
         *             Tags help organize and categorize your AWS AppConfig resources. Each tag consists of a key and an optional value, both of which you define.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder tags(java.util.List<? extends software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags) {
            this.tags = (java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty>)tags;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnDeploymentProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnDeploymentProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnDeploymentProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnDeploymentProps {
        private final java.lang.String applicationId;
        private final java.lang.String configurationProfileId;
        private final java.lang.String configurationVersion;
        private final java.lang.String deploymentStrategyId;
        private final java.lang.String environmentId;
        private final java.lang.String description;
        private final java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> tags;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.applicationId = software.amazon.jsii.Kernel.get(this, "applicationId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configurationProfileId = software.amazon.jsii.Kernel.get(this, "configurationProfileId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.configurationVersion = software.amazon.jsii.Kernel.get(this, "configurationVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.deploymentStrategyId = software.amazon.jsii.Kernel.get(this, "deploymentStrategyId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.environmentId = software.amazon.jsii.Kernel.get(this, "environmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tags = software.amazon.jsii.Kernel.get(this, "tags", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.applicationId = java.util.Objects.requireNonNull(builder.applicationId, "applicationId is required");
            this.configurationProfileId = java.util.Objects.requireNonNull(builder.configurationProfileId, "configurationProfileId is required");
            this.configurationVersion = java.util.Objects.requireNonNull(builder.configurationVersion, "configurationVersion is required");
            this.deploymentStrategyId = java.util.Objects.requireNonNull(builder.deploymentStrategyId, "deploymentStrategyId is required");
            this.environmentId = java.util.Objects.requireNonNull(builder.environmentId, "environmentId is required");
            this.description = builder.description;
            this.tags = (java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty>)builder.tags;
        }

        @Override
        public final java.lang.String getApplicationId() {
            return this.applicationId;
        }

        @Override
        public final java.lang.String getConfigurationProfileId() {
            return this.configurationProfileId;
        }

        @Override
        public final java.lang.String getConfigurationVersion() {
            return this.configurationVersion;
        }

        @Override
        public final java.lang.String getDeploymentStrategyId() {
            return this.deploymentStrategyId;
        }

        @Override
        public final java.lang.String getEnvironmentId() {
            return this.environmentId;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.appconfig.CfnDeployment.TagsProperty> getTags() {
            return this.tags;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("applicationId", om.valueToTree(this.getApplicationId()));
            data.set("configurationProfileId", om.valueToTree(this.getConfigurationProfileId()));
            data.set("configurationVersion", om.valueToTree(this.getConfigurationVersion()));
            data.set("deploymentStrategyId", om.valueToTree(this.getDeploymentStrategyId()));
            data.set("environmentId", om.valueToTree(this.getEnvironmentId()));
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getTags() != null) {
                data.set("tags", om.valueToTree(this.getTags()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_appconfig.CfnDeploymentProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnDeploymentProps.Jsii$Proxy that = (CfnDeploymentProps.Jsii$Proxy) o;

            if (!applicationId.equals(that.applicationId)) return false;
            if (!configurationProfileId.equals(that.configurationProfileId)) return false;
            if (!configurationVersion.equals(that.configurationVersion)) return false;
            if (!deploymentStrategyId.equals(that.deploymentStrategyId)) return false;
            if (!environmentId.equals(that.environmentId)) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            return this.tags != null ? this.tags.equals(that.tags) : that.tags == null;
        }

        @Override
        public final int hashCode() {
            int result = this.applicationId.hashCode();
            result = 31 * result + (this.configurationProfileId.hashCode());
            result = 31 * result + (this.configurationVersion.hashCode());
            result = 31 * result + (this.deploymentStrategyId.hashCode());
            result = 31 * result + (this.environmentId.hashCode());
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.tags != null ? this.tags.hashCode() : 0);
            return result;
        }
    }
}
